summaryrefslogtreecommitdiffstats
path: root/kicker/menuext/prefmenu/prefmenu.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/menuext/prefmenu/prefmenu.cpp')
-rw-r--r--kicker/menuext/prefmenu/prefmenu.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kicker/menuext/prefmenu/prefmenu.cpp b/kicker/menuext/prefmenu/prefmenu.cpp
index 0c072e026..fc32de55d 100644
--- a/kicker/menuext/prefmenu/prefmenu.cpp
+++ b/kicker/menuext/prefmenu/prefmenu.cpp
@@ -84,7 +84,7 @@ void PrefMenu::insertMenuItem(KService::Ptr& s,
if (KickerSettings::menuEntryFormat() == KickerSettings::NameAndDescription)
{
if (!suppressGenericNames ||
- !suppressGenericNames->contains(s->untranslatedGenericName()))
+ !suppressGenericNames->tqcontains(s->untranslatedGenericName()))
{
serviceName = TQString("%1 (%2)").arg(serviceName).arg(comment);
}
@@ -119,8 +119,8 @@ void PrefMenu::insertMenuItem(KService::Ptr& s,
}
// item names may contain ampersands. To avoid them being converted
- // to accelerators, replace them with two ampersands.
- serviceName.replace("&", "&&");
+ // to accelerators, tqreplace them with two ampersands.
+ serviceName.tqreplace("&", "&&");
int newId = insertItem(KickerLib::menuIconSet(s->icon()), serviceName, nId, nIndex);
m_entryMap.insert(newId, static_cast<KSycocaEntry*>(s));
@@ -155,7 +155,7 @@ void PrefMenu::mouseMoveEvent(TQMouseEvent * ev)
return;
}
- if (!m_entryMap.contains(id))
+ if (!m_entryMap.tqcontains(id))
{
kdDebug(1210) << "Cannot find service with menu id " << id << endl;
return;
@@ -224,7 +224,7 @@ void PrefMenu::dragEnterEvent(TQDragEnterEvent *event)
void PrefMenu::dragLeaveEvent(TQDragLeaveEvent */*event*/)
{
// see PrefMenu::dragEnterEvent why this is nescessary
- if (!frameGeometry().contains(TQCursor::pos()))
+ if (!frameGeometry().tqcontains(TQCursor::pos()))
{
KURLDrag::setTarget(0);
}
@@ -296,8 +296,8 @@ void PrefMenu::initialize()
}
// Item names may contain ampersands. To avoid them being converted
- // to accelerators, replace each ampersand with two ampersands.
- groupCaption.replace("&", "&&");
+ // to accelerators, tqreplace each ampersand with two ampersands.
+ groupCaption.tqreplace("&", "&&");
PrefMenu* m = new PrefMenu(g->name(), g->relPath(), this);
m->setCaption(groupCaption);
@@ -323,7 +323,7 @@ void PrefMenu::initialize()
void PrefMenu::slotExec(int id)
{
- if (!m_entryMap.contains(id))
+ if (!m_entryMap.tqcontains(id))
{
return;
}